@@ -1,21 +1,23 @@
 import argparse
 import os
+import re
 from pathlib import Path
-import time
-from typing import List, Optional
+from typing import Any, List, Optional
 from orionis.app import Orionis
 from orionis.console.args.argument import CLIArgument
 from orionis.console.base.command import BaseCommand
 from orionis.console.base.contracts.command import IBaseCommand
+from orionis.console.contracts.reactor import IReactor
+from orionis.console.enums.command import Command
+from orionis.console.exceptions import CLIOrionisValueError
 from orionis.console.output.contracts.console import IConsole
 from orionis.console.output.contracts.executor import IExecutor
 from orionis.foundation.contracts.application import IApplication
 from orionis.services.introspection.modules.reflection import ReflectionModule
-import re
+from orionis.services.log.contracts.log_service import ILogger
+from orionis.support.performance.contracts.counter import IPerformanceCounter
 
-from orionis.services.log.contracts.log_service import ILoggerService
-
-class Reactor:
+class Reactor(IReactor):
 
     def __init__(
         self,
@@ -60,11 +62,14 @@ class Reactor:
         self.__root: str = str(Path.cwd())
 
         # Initialize the internal command registry as an empty dictionary
-        self.__commands: dict = {}
+        self.__commands: dict[str, Command] = {}
 
         # Automatically discover and load command classes from the console commands directory
         self.__loadCommands(str(self.__app.path('console_commands')), self.__root)
 
+        # Load core command classes provided by the Orionis framework
+        self.__loadCoreCommands()
+
         # Initialize the executor for command output management
         self.__executer: IExecutor = self.__app.make('x-orionis.console.output.executor')
 
@@ -72,7 +77,68 @@ class Reactor:
         self.__console: IConsole = self.__app.make('x-orionis.console.output.console')
 
         # Initialize the logger service for logging command execution details
-        self.__logger: ILoggerService = self.__app.make('x-orionis.services.log.log_service')
+        self.__logger: ILogger = self.__app.make('x-orionis.services.log.log_service')
+
+        # Initialize the performance counter for measuring command execution time
+        self.__performance_counter: IPerformanceCounter = self.__app.make('x-orionis.support.performance.counter')
+
+    def __loadCoreCommands(self) -> None:
+        """
+        Loads and registers core command classes provided by the Orionis framework.
+
+        This method is responsible for discovering and registering core command classes
+        that are bundled with the Orionis framework itself (such as version, help, etc.).
+        These commands are essential for the framework's operation and are made available
+        to the command registry so they can be executed like any other user-defined command.
+
+        The method imports the required core command classes, validates their structure,
+        and registers them in the internal command registry. Each command is checked for
+        required attributes such as `timestamps`, `signature`, `description`, and `arguments`
+        to ensure proper integration and discoverability.
+
+        Returns
+        -------
+        None
+            This method does not return any value. All discovered core commands are
+            registered internally in the reactor's command registry for later lookup
+            and execution.
+        """
+
+        # Import the core command class for version
+        from orionis.console.commands.version import VersionCommand
+        from orionis.console.commands.help import HelpCommand
+        from orionis.console.commands.test import TestCommand
+        from orionis.console.commands.publisher import PublisherCommand
+        from orionis.console.commands.workflow import WorkFlowGithubCommand
+        from orionis.console.commands.cache import CacheClearCommand
+
+        # List of core command classes to load (extend this list as more core commands are added)
+        core_commands = [
+            VersionCommand,
+            HelpCommand,
+            TestCommand,
+            PublisherCommand,
+            WorkFlowGithubCommand,
+            CacheClearCommand
+        ]
+
+        # Iterate through the core command classes and register them
+        for obj in core_commands:
+
+            # Validate and extract required command attributes
+            timestamp = self.__ensureTimestamps(obj)
+            signature = getattr(obj, 'signature', None)
+            description = self.__ensureDescription(obj)
+            args = self.__ensureArguments(obj)
+
+            # Register the command in the internal registry with all its metadata
+            self.__commands[signature] = Command(
+                obj=obj,
+                timestamps=timestamp,
+                signature=signature,
+                description=description,
+                args=args
+            )
 
     def __loadCommands(self, commands_path: str, root_path: str) -> None:
         """
@@ -147,13 +213,13 @@ class Reactor:
                             args = self.__ensureArguments(obj)
 
                             # Add the command to the internal registry
-                            self.__commands[signature] = {
-                                "class": obj,
-                                "timestamps": timestamp,
-                                "signature": signature,
-                                "description": description,
-                                "args": args
-                            }
+                            self.__commands[signature] = Command(
+                                obj=obj,
+                                timestamps=timestamp,
+                                signature=signature,
+                                description=description,
+                                args=args
+                            )
 
     def __ensureTimestamps(self, obj: IBaseCommand) -> bool:
         """
@@ -342,107 +408,277 @@ class Reactor:
         # Return the configured ArgumentParser
         return arg_parser
 
+    def __parseArgs(
+        self,
+        command: Command,
+        args: Optional[List[str]] = None
+    ) -> dict:
+        """
+        Parses command-line arguments for a given command using its internal ArgumentParser.
+
+        This method takes a command object and an optional list of command-line arguments,
+        and parses them into a dictionary of argument names and values. If the command
+        defines an ArgumentParser (i.e., expects arguments), the arguments are parsed
+        accordingly. If no arguments are expected or provided, an empty dictionary is returned.
+
+        Parameters
+        ----------
+        command : Command
+            The command object containing the argument parser and metadata.
+        args : Optional[List[str]], default None
+            A list of command-line arguments to parse. If None, an empty list is used.
+
+        Returns
+        -------
+        dict
+            A dictionary containing the parsed argument names and their corresponding values.
+            Returns an empty dictionary if no arguments are expected or provided.
+
+        Raises
+        ------
+        SystemExit
+            Raised by argparse if argument parsing fails or if help is requested.
+        """
+
+        # Initialize parsed_args to None
+        parsed_args = None
+
+        # If the command expects arguments, parse them using its ArgumentParser
+        if command.args is not None and isinstance(command.args, argparse.ArgumentParser):
+            if args is None:
+                args = []
+            try:
+                # Parse the provided arguments using the command's ArgumentParser
+                parsed_args = command.args.parse_args(args)
+            except SystemExit:
+                # Allow argparse to handle help/error messages and exit
+                raise
+
+        # Convert the parsed arguments to a dictionary and return
+        if isinstance(parsed_args, argparse.Namespace):
+            return vars(parsed_args)
+        elif isinstance(parsed_args, dict):
+            return parsed_args
+        else:
+            # Return an empty dictionary if no arguments were parsed
+            return {}
+
+    def info(self) -> List[dict]:
+        """
+        Retrieves a list of all registered commands with their metadata.
+
+        This method returns a list of dictionaries, each containing information about
+        a registered command, including its signature, description, and whether it has
+        timestamps enabled. This is useful for introspection and displaying available
+        commands to the user.
+
+        Returns
+        -------
+        List[dict]
+            A list of dictionaries representing the registered commands, where each dictionary
+            contains the command's signature, description, and timestamps status.
+        """
+
+        # Prepare a list to hold command information
+        commands_info = []
+
+        # Iterate through all registered commands in the internal registry
+        for command in self.__commands.values():
+
+            # Extract command metadata
+            signature:str = command.signature
+            description:str = command.description
+
+            # Skip internal commands (those with double underscores)
+            if signature.startswith('__') and signature.endswith('__'):
+                continue
+
+            # Append command information to the list
+            commands_info.append({
+                "signature": signature,
+                "description": description
+            })
+
+        # Return the sorted list of command information by signature
+        return sorted(commands_info, key=lambda x: x['signature'])
+
     def call(
         self,
         signature: str,
         args: Optional[List[str]] = None
-    ):
+    ) -> Optional[Any]:
         """
-        Executes a command by its signature with optional command-line arguments.
+        Executes a registered command synchronously by its signature, optionally passing command-line arguments.
 
-        This method retrieves a registered command by its signature, validates any provided
-        arguments against the command's argument parser, and executes the command's handle
-        method with the parsed arguments and application context.
+        This method retrieves a command from the internal registry using its unique signature,
+        validates and parses any provided arguments using the command's argument parser,
+        and then executes the command's `handle` method synchronously. It manages execution timing,
+        logging, and error handling, and returns any output produced by the command.
 
         Parameters
         ----------
         signature : str
             The unique signature identifier of the command to execute.
         args : Optional[List[str]], default None
-            Command-line arguments to pass to the command. If None, no arguments are provided.
+            List of command-line arguments to pass to the command. If None, no arguments are provided.
 
         Returns
         -------
-        None
-            This method does not return any value. The command's handle method is called
-            directly for execution.
+        Optional[Any]
+            The output produced by the command's `handle` method if execution is successful.
+            Returns None if the command does not produce a result or if an error occurs.
 
         Raises
         ------
-        ValueError
+        CLIOrionisValueError
             If the command with the specified signature is not found in the registry.
         SystemExit
-            If argument parsing fails due to invalid arguments provided.
+            If argument parsing fails due to invalid arguments provided (raised by argparse).
+        Exception
+            Propagates any exception raised during command execution after logging and error output.
+
+        Notes
+        -----
+        - Logs execution start, completion, and errors with timestamps if enabled.
+        - Handles argument parsing and injects parsed arguments into the command instance.
+        - All exceptions are logged and displayed in the console.
         """
 
-        # Retrieve the command from the registry
-        command: dict = self.__commands.get(signature)
+        # Retrieve the command from the registry by its signature
+        command: Command = self.__commands.get(signature)
         if command is None:
-            raise ValueError(f"Command '{signature}' not found.")
+            raise CLIOrionisValueError(f"Command '{signature}' not found.")
 
-        # Start execution timer
-        start_time = time.perf_counter()
+        # Start execution timer for performance measurement
+        self.__performance_counter.start()
 
-        # Get command details
-        command_class = command.get("class")
-        arg_parser: Optional[argparse.ArgumentParser] = command.get("args")
-        timestamps: bool = command.get("timestamps")
-
-        # Initialize parsed arguments
-        parsed_args = None
-
-        # If the command has arguments and args were provided, validate them
-        if arg_parser is not None and isinstance(arg_parser, argparse.ArgumentParser):
-            if args is None:
-                args = []
-            try:
-                # Parse the provided arguments using the command's ArgumentParser
-                parsed_args = arg_parser.parse_args(args)
-            except SystemExit:
-                # Re-raise SystemExit to allow argparse to handle help/error messages
-                raise
-
-        # Log the command execution start with RUNNING state
-        if timestamps:
+        # Log the command execution start with RUNNING state if timestamps are enabled
+        if command.timestamps:
             self.__executer.running(program=signature)
 
         try:
+            # Instantiate the command class using the application container
+            command_instance: IBaseCommand = self.__app.make(command.obj)
 
-            # Create an instance of the command class and execute it
-            command_instance: IBaseCommand = self.__app.make(command_class)
+            # Inject parsed arguments into the command instance
+            command_instance._args = self.__parseArgs(command, args)
 
-            # If arguments were parsed, set them on the command instance
-            if isinstance(parsed_args, argparse.Namespace):
-                command_instance._args = vars(parsed_args)
-            elif isinstance(parsed_args, dict):
-                command_instance._args = parsed_args
-            else:
-                command_instance._args = {}
+            # Execute the command's handle method and capture its output
+            output = self.__app.call(command_instance, 'handle')
 
-            # Call the handle method of the command instance
-            output =  self.__app.call(command_instance, 'handle')
-
-            # Log the command execution completion with DONE state
-            if timestamps:
-                elapsed_time = round(time.perf_counter() - start_time, 2)
+            # Calculate elapsed time and log completion with DONE state if command.timestamps are enabled
+            elapsed_time = round(self.__performance_counter.stop(), 2)
+            if command.timestamps:
                 self.__executer.done(program=signature, time=f"{elapsed_time}s")
 
-            # Log the command execution success
+            # Log successful execution in the logger service
             self.__logger.info(f"Command '{signature}' executed successfully in ({elapsed_time}) seconds.")
 
-            # If the command has a return value or output, return it
-            if output is not None:
-                return output
+            # Return the output produced by the command, if any
+            return output
 
         except Exception as e:
-
-            # Display the error message in the console
+            # Display the error message in the console (without timestamp)
             self.__console.error(f"An error occurred while executing command '{signature}': {e}", timestamp=False)
 
             # Log the error in the logger service
             self.__logger.error(f"Command '{signature}' execution failed: {e}")
 
-            # Log the command execution failure with ERROR state
-            if timestamps:
-                elapsed_time = round(time.perf_counter() - start_time, 2)
+            # Calculate elapsed time and log failure with ERROR state if command.timestamps are enabled
+            elapsed_time = round(self.__performance_counter.stop(), 2)
+            if command.timestamps:
                 self.__executer.fail(program=signature, time=f"{elapsed_time}s")
+
+            # Propagate the exception after logging
+            raise
+
+    async def callAsync(
+        self,
+        signature: str,
+        args: Optional[List[str]] = None
+    ) -> Optional[Any]:
+        """
+        Executes a registered command asynchronously by its signature, optionally passing command-line arguments.
+
+        This method locates a command in the internal registry using its unique signature,
+        validates and parses any provided arguments using the command's argument parser,
+        and then executes the command's `handle` method asynchronously. It manages execution timing,
+        logging, and error handling, and returns any output produced by the command.
+
+        Parameters
+        ----------
+        signature : str
+            The unique signature identifier of the command to execute.
+        args : Optional[List[str]], default None
+            List of command-line arguments to pass to the command. If None, no arguments are provided.
+
+        Returns
+        -------
+        Optional[Any]
+            The output produced by the command's `handle` method if execution is successful.
+            Returns None if the command does not produce a result or if an error occurs.
+
+        Raises
+        ------
+        CLIOrionisValueError
+            If the command with the specified signature is not found in the registry.
+        SystemExit
+            If argument parsing fails due to invalid arguments provided (raised by argparse).
+        Exception
+            Propagates any exception raised during command execution after logging and error output.
+
+        Notes
+        -----
+        - Logs execution start, completion, and errors with timestamps if enabled.
+        - Handles argument parsing and injects parsed arguments into the command instance.
+        - All exceptions are logged and displayed in the console.
+        """
+
+        # Retrieve the command from the registry by its signature
+        command: Command = self.__commands.get(signature)
+        if command is None:
+            raise CLIOrionisValueError(f"Command '{signature}' not found.")
+
+        # Start execution timer for performance measurement
+        self.__performance_counter.start()
+
+        # Log the command execution start with RUNNING state if timestamps are enabled
+        if command.timestamps:
+            self.__executer.running(program=signature)
+
+        try:
+            # Instantiate the command class using the application container
+            command_instance: IBaseCommand = self.__app.make(command.obj)
+
+            # Inject parsed arguments into the command instance
+            command_instance._args = self.__parseArgs(command, args)
+
+            # Execute the command's handle method asynchronously and capture its output
+            output = await self.__app.callAsync(command_instance, 'handle')
+
+            # Calculate elapsed time and log completion with DONE state if command.timestamps are enabled
+            elapsed_time = round(self.__performance_counter.stop(), 2)
+            if command.timestamps:
+                self.__executer.done(program=signature, time=f"{elapsed_time}s")
+
+            # Log successful execution in the logger service
+            self.__logger.info(f"Command '{signature}' executed successfully in ({elapsed_time}) seconds.")
+
+            # Return the output produced by the command, if any
+            return output
+
+        except Exception as e:
+
+            # Display the error message in the console (without timestamp)
+            self.__console.error(f"An error occurred while executing command '{signature}': {e}", timestamp=False)
+
+            # Log the error in the logger service
+            self.__logger.error(f"Command '{signature}' execution failed: {e}")
+
+            # Calculate elapsed time and log failure with ERROR state if command.timestamps are enabled
+            elapsed_time = round(self.__performance_counter.stop(), 2)
+            if command.timestamps:
+                self.__executer.fail(program=signature, time=f"{elapsed_time}s")
+
+            # Propagate the exception after logging
+            raise
\ No newline at end of file
